@@ -19,7 +19,7 @@ import collections
 from pyramid.response import Response
 from sqlalchemy import create_engine
 
-from tropofy.database import read_write_xl
+from tropofy.file_io import read_write_xl
 from data_set import AppDataSet
 from tropofy.widgets import DataSets, ExecuteFunction
 from tropofy.database import DBSession
@@ -166,7 +166,7 @@ class App(object):
         return self.get_dependency_ordered_dict_of_tables_mapped_to_classes_for_app().keys()
 
     def get_data_set_as_excel_wb_string_repr(self, data_set):
-        return read_write_xl.create_excel_string_repr(data_set)
+        return read_write_xl.ExcelWriter.create_excel_string_repr(data_set)
 
     def export_data_set(self, data_set):
         response = Response(self.get_data_set_as_excel_wb_string_repr(data_set))
