@@ -22,5 +22,5 @@ from chart_widget.chart_widget import Chart, FilteredChart
 from execute_function_widget.execute_function_widget import ExecuteFunction
 from image_widget.image_widget import StaticImage
 from custom_export_widget.custom_export_widget import CustomExport, ExportDataSet
-from form_widget.form_widget import Form, ParameterForm, Filter
+from form_widget.form_widget import Form, ParameterForm, Filter, FilterMixin
 from data_sets_widget.data_sets_widget import DataSets
